@@ -12,6 +12,8 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
   before_action :apply_diff_view_cookie!, only: [:diffs, :diff_for_path]
   before_action :build_merge_request, except: [:create]
 
+  feature_category :continuous_integration, [:pipelines]
+
   urgency :low, [
     :new,
     :create,
@@ -29,12 +31,14 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
 
   def new
     define_new_vars
-    return unless rapid_diffs?
 
-    # load 'rapid_diffs' javascript entrypoint instead of 'new'
-    @js_action_name = 'rapid_diffs'
-    define_rapid_diffs_vars
-    render action: :rapid_diffs
+    @rapid_diffs_presenter = ::RapidDiffs::MergeRequestCreationPresenter.new(
+      @merge_request,
+      project,
+      diff_view,
+      diff_options,
+      { merge_request: merge_request_params }
+    )
   end
 
   def create
@@ -112,8 +116,8 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
     render json: ProjectSerializer.new.represent(get_target_projects)
   end
 
-  def diffs_resource
-    @merge_request&.compare&.diffs
+  def diffs_resource(options = {})
+    @merge_request&.compare&.diffs(options)
   end
 
   private
@@ -130,7 +134,7 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
     @source_project = @merge_request.source_project
 
     recent_commits = @merge_request.recent_commits(
-      load_from_gitaly: Feature.enabled?(:commits_from_gitaly, @target_project)
+      load_from_gitaly: true
     ).with_latest_pipeline(@merge_request.source_branch)
 
     @commits = set_commits_for_rendering(
@@ -149,21 +153,6 @@ class Projects::MergeRequests::CreationsController < Projects::MergeRequests::Ap
     set_pipeline_variables
   end
 
-  def rapid_diffs?
-    params[:rapid_diffs_disabled] != 'true' &&
-      ::Feature.enabled?(:rapid_diffs, current_user, type: :wip) &&
-      ::Feature.enabled?(:rapid_diffs_on_mr_creation, current_user, type: :wip)
-  end
-
-  def define_rapid_diffs_vars
-    merge_request = { source_branch: @merge_request.source_branch, target_branch: @merge_request.target_branch }
-    @show_whitespace_default = current_user.nil? || current_user.show_whitespace_in_diffs
-    @stream_url = project_new_merge_request_diffs_stream_path(@project, merge_request: merge_request)
-    @reload_stream_url = project_new_merge_request_diffs_stream_path(@project, merge_request: merge_request)
-    @diff_files_endpoint = project_new_merge_request_diff_files_metadata_path(@project, merge_request: merge_request)
-    @diffs_stats_endpoint = project_new_merge_request_diffs_stats_path(@project, merge_request: merge_request)
-  end
-
   # rubocop: disable CodeReuse/ActiveRecord
   def selected_target_project
     return @project unless @project.forked?
