@@ -295,11 +295,16 @@ module BlobHelper
       user_id: current_user.present? ? current_user.to_global_id : '',
       target_branch: selected_branch,
       original_branch: ref,
-      can_download_code: can?(current_user, :download_code, project).to_s
+      escaped_ref: ActionDispatch::Journey::Router::Utils.escape_path(ref),
+      can_download_code: can?(current_user, :download_code, project).to_s,
+      full_name: project.name_with_namespace,
+      has_revs_file: (!project.repository.ignore_revs_file_blob.nil?).to_s
     }
   end
 
   def vue_blob_header_app_data(project, blob, ref)
+    archive_prefix = ref ? "#{project.path}-#{ref.tr('/', '-')}" : ''
+
     {
       blob_path: blob.path,
       is_binary: blob.binary?,
@@ -312,7 +317,11 @@ module BlobHelper
       project_short_path: project.path,
       ref_type: @ref_type.to_s,
       ref: ref,
-      root_ref: project.repository.root_ref
+      root_ref: project.repository.root_ref,
+      ssh_url: ssh_enabled? ? ssh_clone_url_to_repo(project) : '',
+      http_url: http_enabled? ? http_clone_url_to_repo(project) : '',
+      xcode_url: show_xcode_link?(project) ? xcode_uri_to_repo(project) : '',
+      download_links: archive_download_links(project, ref, archive_prefix).to_json
     }
   end
 
@@ -345,6 +354,19 @@ module BlobHelper
       last_commit_sha: @last_commit_sha
     }
   end
+
+  private
+
+  def archive_download_links(project, ref, archive_prefix)
+    Gitlab::Workhorse::ARCHIVE_FORMATS.map do |fmt|
+      {
+        text: fmt,
+        path: external_storage_url_or_path(
+          project_archive_path(project, id: tree_join(ref, archive_prefix), format: fmt)
+        )
+      }
+    end
+  end
 end
 
 BlobHelper.prepend_mod_with('BlobHelper')
