@@ -59,7 +59,7 @@ module Ci
         pipeline_schedules_path: pipeline_schedules_path(project),
         can_create_pipeline: can?(current_user, :create_pipeline, project).to_s,
         new_pipeline_path: can?(current_user, :create_pipeline, project) && new_project_pipeline_path(project),
-        reset_cache_path: can_any?(current_user, [:admin_pipeline, :admin_runner], project) && reset_cache_project_settings_ci_cd_path(project),
+        reset_cache_path: can_any?(current_user, [:admin_pipeline, :admin_runners], project) && reset_cache_project_settings_ci_cd_path(project),
         has_gitlab_ci: has_gitlab_ci?(project).to_s,
         pipeline_editor_path: can?(current_user, :create_pipeline, project) && project_ci_pipeline_editor_path(project),
         suggested_ci_templates: suggested_ci_templates.to_json,
