@@ -7,6 +7,8 @@ module Ci
     self.table_name = :ci_runner_taggings
     self.primary_key = :id
 
+    ignore_column :sharding_key_id, remove_with: '18.6', remove_after: '2025-10-22'
+
     query_constraints :runner_id, :runner_type
 
     before_validation :set_runner_type, on: :create, if: -> { runner_type.nil? && runner }
@@ -19,7 +21,9 @@ module Ci
     belongs_to :tag, class_name: 'Ci::Tag', optional: false
 
     validates :runner_type, presence: true
-    validate :check_sharding_key_id
+    validates :organization_id, presence: true, on: [:create, :update], unless: :instance_type?
+
+    validate :no_organization_id, if: :instance_type?
 
     scope :scoped_runners, -> do
       where(arel_table[:runner_id].eq(Ci::Runner.arel_table[Ci::Runner.primary_key]))
@@ -33,16 +37,10 @@ module Ci
       self.runner_type = runner.runner_type
     end
 
-    def check_sharding_key_id
-      if runner_type == 'instance_type'
-        return if sharding_key_id.nil?
+    def no_organization_id
+      return if organization_id.nil?
 
-        errors.add(:sharding_key_id, 'instance_type runners must not have a sharding_key_id')
-      else
-        return if sharding_key_id.present?
-
-        errors.add(:sharding_key_id, 'non-instance_type runners must have a sharding_key_id')
-      end
+      errors.add(:organization_id, 'instance_type runners must not have an organization_id')
     end
   end
 end
