@@ -29,8 +29,6 @@ module Banzai
           Filter::AttributesFilter,
           Filter::VideoLinkFilter,
           Filter::AudioLinkFilter,
-          Filter::TableOfContentsLegacyFilter,
-          Filter::TableOfContentsTagLegacyFilter,
           Filter::TableOfContentsTagFilter,
           Filter::AutolinkFilter,
           Filter::SuggestionFilter,
@@ -63,7 +61,8 @@ module Banzai
           Filter::References::MilestoneReferenceFilter,
           Filter::References::AlertReferenceFilter,
           Filter::References::FeatureFlagReferenceFilter,
-          Filter::References::CommitReferenceFilter
+          Filter::References::CommitReferenceFilter,
+          Filter::References::WikiPageReferenceFilter
         ]
       end
 
